MODULE statfun
!module with statistical function
IMPLICIT NONE

 CONTAINS

 FUNCTION planck(freq,tep,ier)
!
!	calculates intensity of the black body radiation
!		IF   ier<0  freq [cm], planck[erg/S/cm**2/cm]
!		     ier=0  freq [Angst.], planck [erg/s/cm**2/Angstrom]
!		     ier>0  freq [1/S], planck [erg/s/cm**2/Hz]
!
 IMPLICIT NONE
 
 INTEGER:: ier
 
 REAL(KIND=8):: planck
 REAL(KIND=8):: freq,tep
 
  IF (ier < 0) THEN
     planck=1.1904397d-5/freq**5/(EXP(1.438769d0/freq/tep)-1.D0)
  ELSE IF (ier == 0) THEN
     planck=1.1904397d27/freq**5/(EXP(1.438769d8/freq/tep)-1.D0)
  ELSE
      planck=1.474501d-47*freq*freq*freq/(EXP(4.799216d-11*freq/tep)-1.D0)
  ENDIF

 END FUNCTION planck

 FUNCTION voigt(x,y)

!	taken from the old Synspec code:
! Hubeny I., Lanz T., Jeffery C.S., 1994, in Newsletter on Analysis
! of Astronomical spectra No.20, ed. C.S. Jeffery (CCP7; St. Andrews:
! St. Andrews Univ.), 30
!   	HUMLICEK VOIGT FUNCTION ALGORITHM  (LOWER PRECISION VERSION)

  IMPLICIT NONE
  
  REAL(KIND=8):: voigt
  REAL(KIND=8):: x,y
  REAL(KIND=8):: wr,y1,y2,d,d1,d2,d3,d4,r
  REAL(KIND=8), DIMENSION(6):: t=(/0.314240376D0,0.947788391D0,1.59768264D0,2.27950708D0,3.02063703D0,3.8897249D0/),&
                       c=(/1.01172805D0,-.75197147D0,1.2557727D-2,1.00220082D-2,-2.42068135D-4,5.00848061D-7/),&
                       s=(/1.393237D0,.231152406D0,-.155351466D0,6.21836624D-3,9.19082986D-5,-6.27525958D-7/)

  INTEGER:: i 

   wr=0.0D0
   y1 = y + 1.5D0
   y2 = y1*y1

   DO i=1,6
      r=x-t(i)
      d=1.D0/(r*r+y2)
      d1=y1*d
      d2=r*d
      r=x+t(i)
      d=1.D0/(r*r+y2)
      d3=y1*d
      d4=r*d
      wr=wr+c(i)*(d1+d3)-s(i)*(d2-d4)
   END DO

    voigt=DBLE(wr)
 END FUNCTION voigt


 FUNCTION bolt(temp,g1,g2,pot,iriad)

 USE unitchange	

  IMPLICIT NONE
!     temp -temperature [K]			     
!     g1   -statistical weight of the lower level -m	     
!     g2   -statistical weight of the upper level -n	     
!     pot  -energy diference (upper-lower level) [ev], pot>0  
!     output - population ratio N(n)/N(m) 		       
!     
! OR IF:            
!     
!     temp -temperature [K]			       
!     g2   -statistical weight of the level-n		       
!     g1   -partition function of the ion                      
!     pot  -excitation potencial of the n-th level [eV]	       
!           (with respect to ground state), pot>0	       
!     output -ratio N(n)/N, (n-th level population to	       
!          -the ion population	
!	       
! OR IF:
!     
!     iriad=1  pot is in [1/cm]         		       !
!

 REAL(KIND=8):: bolt
 REAL(KIND=8):: temp,pot
 REAL(KIND=8):: g1,g2
 
 INTEGER:: iriad


 
    IF (iriad == 1) THEN
	  bolt=g2/(g1*EXP(2.302585d0*5039.77d0/temp*pot/evcm))
    ELSE
	  bolt=g2/(g1*EXP(2.302585d0*5039.77d0/temp*pot))
    ENDIF
	
 END FUNCTION bolt

 FUNCTION sah(te,ek,zp,s1,s2)

 IMPLICIT NONE

 REAL(KIND=8)::te,ek,zp,s1,s2,sah

!          SAHA EQUATION (RATIO OF THE NUMBER DENSITIES OF
!		TWO ADJACENT IONS)
!          ZP -in [EV], TE -in [K], EK -in [cm^-3]

 sah=4.8293745d15*s2/s1*sqrt(te)**3 &
     *exp(-1.16045059d4/te*zp)/ek

 END FUNCTION sah

 FUNCTION sahan(te,zp,s1,s2)

 IMPLICIT NONE

 REAL(KIND=8)::te,zp,s1,s2,sahan

!          PART OF SAHA EQUATION WITHOUT ELECTRON NUMBER DENSITY
!          ZP -in [EV], TE -in [K]

 sahan=4.8293745d15*s2/s1*sqrt(te)**3*exp(-1.16045059d4/te*zp)

 END FUNCTION sahan

 FUNCTION gaunt(i,fr)
!	taken from the Syspec code:
!       Hubeny I., Lanz T., Jeffery C.S., 1994, in Newsletter on Analysis
!       of Astronomical spectra No.20, ed. C.S. Jeffery (CCP7; St. Andrews:
!       St. Andrews Univ.), 30
!
!       Hydrogenic bound-free Gaunt factor for the principal quantum
!     number I and frequency FR
!
  IMPLICIT NONE

  INTEGER:: i
  
  REAL(KIND=8):: gaunt
  REAL(KIND=8):: x,fr

  x=fr/2.99793D14
        gaunt=1.D0
  SELECT CASE (i)
     CASE (1)
        gaunt=1.2302628D0+x*(-2.9094219D-3+x*(7.3993579D-6-8.7356966D-9*x))&
              +(12.803223D0/x-5.5759888D0)/x
     CASE (2)
        gaunt=1.1595421D0+x*(-2.0735860D-3+2.7033384D-6*x)+(-1.2709045D0+&
              (-2.0244141D0/x+2.1325684D0)/x)/x
     CASE (3)
        gaunt=1.1450949D0+x*(-1.9366592D-3+2.3572356D-6*x)+(-0.55936432D0+&
              (-0.23387146D0/x+0.52471924D0)/x)/x
     CASE (4)
        gaunt=1.1306695D0+x*(-1.3482273D-3+x*(-4.6949424D-6+2.3548636D-8*x))&
              +(-0.31190730D0+(0.19683564D0-5.4418565D-2/x)/x)/x
     CASE (5)
        gaunt=1.1190904D0+x*(-1.0401085D-3+x*(-6.9943488D-6+2.8496742D-8*x))&
              +(-0.16051018D0+(5.5545091D-2-8.9182854D-3/x)/x)/x
     CASE (6)
        gaunt=1.1168376D0+x*(-8.9466573D-4+x*(-8.8393133D-6+3.4696768D-8*x))&
              +(-0.13075417D0+(4.1921183D-2-5.5303574D-3/x)/x)/x
     CASE (7)
        gaunt=1.1128632D0+x*(-7.4833260D-4+x*(-1.0244504D-5+3.8595771D-8*x))&
              +(-9.5441161D-2+(2.3350812D-2-2.2752881D-3/x)/x)/x
     CASE (8)
        gaunt=1.1093137D0+x*(-6.2619148D-4+x*(-1.1342068D-5+4.1477731D-8*x))&
              +(-7.1010560D-2+(1.3298411D-2 -9.7200274D-4/x)/x)/x
     CASE (9)
        gaunt=1.1078717D0+x*(-5.4837392D-4+x*(-1.2157943D-5+4.3796716D-8*x))&
              +(-5.6046560D-2+(8.5139736D-3-4.9576163D-4/x)/x)/x
     CASE (10)
        gaunt=1.1052734D0+x*(-4.4341570D-4+x*(-1.3235905D-5+4.7003140D-8*x))&
              +(-4.7326370D-2+(6.1516856D-3-2.9467046D-4/x)/x)/x
     CASE DEFAULT
  END SELECT
    
 END FUNCTION gaunt

 FUNCTION gfree(t,fr)
!	taken from the Syspec code:
!       Hubeny I., Lanz T., Jeffery C.S., 1994, in Newsletter on Analysis
!       of Astronomical spectra No.20, ed. C.S. Jeffery (CCP7; St. Andrews:
!       St. Andrews Univ.), 30
!
!	Hydrogenic free-free Gaunt factor, for temperature T and
!	frequency FR
!
  IMPLICIT NONE

  REAL(KIND=8):: t,fr,gfree
  REAL(KIND=8):: x,thet,c1,c2,c3,c4

  thet=5040.4D0/t
  
  IF (thet < 4.d-2) thet=4.d-2
 	x=fr/2.99793D14
  
  IF (x < 1) THEN
     
     IF(x < 0.2D0) X=0.2D0 
     gfree=(1.0823D0+2.98D-2/thet)+(6.7D-3+1.12D-2/thet)/x
  
  ELSE 
     c1=(3.9999187D-3-7.8622889D-5/thet)/thet+1.070192D0
     c2=(6.4628601D-2-6.1953813D-4/thet)/thet+2.6061249D-1
     c3=(1.3983474D-5/thet+3.7542343D-2)/thet+5.7917786D-1
     c4=3.4169006D-1+1.1852264D-2/thet
     gfree=((c4/x-c3)/x+c2)/x+c1
  END IF

 END FUNCTION gfree


 SUBROUTINE state0 (Adyp,Ad,Axi)
!		taken from the Synspec code:
! 	Hubeny I., Lanz T., Jeffery C.S., 1994, 
!	in: Newsletter on Analysis of Astronomical spectra No.20, 
!	ed. C.S. Jeffery (CCP7; St. Andrews: St. Andrews Univ.), 30
!
!  Initialization of the basic parameters for the Saha equation
!
 USE param

 IMPLICIT NONE

!	parameter(matom=99)
 CHARACTER(LEN=4),DIMENSION(matom):: dyp,adyp
 
 REAL(KIND=8),DIMENSION(3,matom)::d,ad
 REAL(KIND=8),DIMENSION(8,matom):: xi,axi
 
 INTEGER::i,j

!
      DATA DYP/' H  ',' He ',' Li ',' Be ',' B  ',' C  ',&
              ' N  ',' O  ',' F  ',' Ne ',' Na ',' Mg ',&
              ' Al ',' Si ',' P  ',' S  ',' Cl ',' Ar ',&
              ' K  ',' Ca ',' Sc ',' Ti ',' V  ',' Cr ',&
              ' Mn ',' Fe ',' Co ',' Ni ',' Cu ',' Zn ',&
              ' Ga ',' Ge ',' As ',' Se ',' Br ',' Kr ',&
              ' Rb ',' Sr ',' Y  ',' Zr ',' Nb ',' Mo ',&
              ' Tc ',' Ru ',' Rh ',' Pd ',' Ag ',' Cd ', &
              ' In ',' Sn ',' Sb ',' Te ',' I  ',' Xe ',&
              ' Cs ',' Ba ',' La ',' Ce ',' Pr ',' Nd ', &
              ' Pm ',' Sm ',' Eu ',' Gd ',' Tb ',' Dy ', &
              ' Ho ',' Er ',' Tm ',' Yb ',' Lu ',' Hf ', &
              ' Ta ',' W  ',' Re ',' Os ',' Ir ',' Pt ',& 
              ' Au ',' Hg ',' Tl ',' Pb ',' Bi ',' Po ',& 
              ' At ',' Rn ',' Fr ',' Ra ',' Ac ',' Th ',& 
              ' Pa ',' U  ',' Np ',' Pu ',' Am ',' Cm ',& 
              ' Bk ',' Cf ',' Es '/
!
! Standard atomic constants for first 99 species 
!   Abundances for the first 30 from Grevesse & Sauval,
!      (1998, Space Sci. Rev. 85, 161)
!
!         Element Atomic  Solar    Std.
!                 weight abundance highest 
! 
!                                  ionization stage 
      DATA D/ 1.008D0, 1.00D0, 2.0D0,&
             4.003D0, 1.00D-1, 3.0D0,&
             6.941D0, 1.26D-11, 4.0D0,&
             9.012D0, 2.51D-11, 5.0D0,&
            10.810D0, 5.0D-10, 5.0D0,&
            12.011D0, 3.31D-4, 5.0D0,&
            14.007D0, 8.32D-5, 5.0D0,&
            16.000D0, 6.76D-4, 5.0D0,&
            18.918D0, 3.16D-8, 5.0D0,&
            20.179D0, 1.23D-4, 5.0D0,&
            22.990D0, 2.14D-6, 5.0D0,&
            24.305D0, 3.80D-5, 5.0D0,&
            26.982D0, 2.95D-6, 5.0D0,&
            28.086D0, 3.55D-5, 5.0D0,&
            30.974D0, 2.82D-7, 5.0D0,&
            32.060D0, 2.14D-5, 5.0D0,&
            35.453D0, 3.16D-7, 5.0D0,&
            39.948D0, 2.52D-6, 5.0D0,&
            39.098D0, 1.32D-7, 5.0D0,&
            40.080D0, 2.29D-6, 5.0D0,&
            44.956D0, 1.48D-9, 5.0D0,&
            47.900D0, 1.05D-7, 5.0D0,&
            50.941D0, 1.00D-8, 5.0D0,&
            51.996D0, 4.68D-7, 5.0D0,&
            54.938D0, 2.45D-7, 5.0D0,&
            55.847D0, 3.16D-5, 5.0D0,&
            58.933D0, 8.32D-8, 5.0D0,&
            58.700D0, 1.78D-6, 5.0D0,&
            63.546D0, 1.62D-8, 5.0D0,&
            65.380D0, 3.98D-8, 5.0D0,&
            69.72D0,   1.34896324D-09  ,  3.0D0,  &
            72.60D0 ,   4.26579633D-09  ,  3.0D0, & 
            74.92D0 ,   2.34422821D-10  ,  3.0D0,  &
            78.96D0 ,   2.23872066D-09  ,  3.0D0,  &
            79.91D0 ,   4.26579633D-10  ,  3.0D0,  &
            83.80D0 ,   1.69824373D-09  ,  3.0D0,  &
            85.48D0 ,   2.51188699D-10  ,  3.0D0,  &
            87.63D0 ,   8.51138173D-10  ,  3.0D0,  &
            88.91D0 ,   1.65958702D-10  ,  3.0D0,  &
            91.22D0 ,   4.07380181D-10  ,  3.0D0,  &
            92.91D0 ,   2.51188630D-11  ,  3.0D0,  & 
            95.95D0 ,   9.12010923D-11  ,  3.0D0,  & 
            99.00D0 ,   1.00000000D-24  ,  3.0D0,  & 
            101.1D0 ,   6.60693531D-11  ,  3.0D0,  & 
            102.9D0 ,   1.23026887D-11  ,  3.0D0,  & 
            106.4D0 ,   5.01187291D-11  ,  3.0D0,  & 
            107.9D0 ,   1.73780087D-11  ,  3.0D0,  & 
            112.4D0 ,   5.75439927D-11  ,  3.0D0,  & 
            114.8D0 ,   6.60693440D-12  ,  3.0D0,  & 
            118.7D0 ,   1.38038460D-10  ,  3.0D0,  & 
            121.8D0 ,   1.09647810D-11  ,  3.0D0,  & 
            127.6D0 ,   1.73780087D-10  ,  3.0D0,  & 
            126.9D0 ,   3.23593651D-11  ,  3.0D0,  & 
            131.3D0 ,   1.69824373D-10  ,  3.0D0,  & 
            132.9D0 ,   1.31825676D-11  ,  3.0D0,  & 
            137.4D0,   1.62181025D-10  ,  3.0D0,  & 
            138.9D0 ,   1.58489337D-11  ,  3.0D0,  & 
            140.1D0 ,   4.07380293D-11  ,  3.0D0,  & 
            140.9D0 ,   6.02559549D-12  ,  3.0D0,  & 
            144.3D0 ,   2.95120943D-11  ,  3.0D0,  & 
            147.0D0 ,   1.00000000D-24  ,  3.0D0,  & 
            150.4D0 ,   9.33254366D-12  ,  3.0D0,  & 
            152.0D0 ,   3.46736869D-12  ,  3.0D0,  & 
            157.3D0 ,   1.17489770D-11  ,  3.0D0,  & 
            158.9D0 ,   2.13796216D-12  ,  3.0D0,  & 
            162.5D0 ,   1.41253747D-11  ,  3.0D0,  & 
            164.9D0 ,   3.16227767D-12  ,  3.0D0,  & 
            167.3D0 ,   8.91250917D-12  ,  3.0D0,  & 
            168.9D0 ,   1.34896287D-12  ,  3.0D0,  & 
            173.0D0 ,   8.91250917D-12  ,  3.0D0,  & 
            175.0D0 ,   1.31825674D-12  ,  3.0D0,  & 
            178.5D0 ,   5.37031822D-12  ,  3.0D0,  & 
            181.0D0 ,   1.34896287D-12  ,  3.0D0,  & 
            183.9D0 ,   4.78630102D-12  ,  3.0D0,  & 
            186.3D0 ,   1.86208719D-12  ,  3.0D0,  & 
            190.2D0 ,   2.39883290D-11  ,  3.0D0,  & 
            192.2D0 ,   2.34422885D-11  ,  3.0D0,  & 
            195.1D0 ,   4.78630036D-11  ,  3.0D0,  & 
            197.0D0 ,   6.76082952D-12  ,  3.0D0,  & 
            200.6D0 ,   1.23026887D-11  ,  3.0D0,  & 
            204.4D0 ,   6.60693440D-12  ,  3.0D0,  & 
            207.2D0 ,   1.12201834D-10  ,  3.0D0,  & 
            209.0D0 ,   5.12861361D-12  ,  3.0D0,  & 
            210.0D0 ,   1.00000000D-24  ,  3.0D0,  & 
            211.0D0 ,   1.00000000D-24  ,  3.0D0,  & 
            222.0D0 ,   1.00000000D-24  ,  3.0D0,  & 
            223.0D0 ,   1.00000000D-24  ,  3.0D0,  & 
            226.1D0 ,   1.00000000D-24  ,  3.0D0,  & 
            227.1D0 ,   1.00000000D-24  ,  3.0D0,  & 
            232.0D0 ,   1.20226443D-12  ,  3.0D0,  & 
            231.0D0 ,   1.00000000D-24  ,  3.0D0,  &
            238.0D0 ,   3.23593651D-13  ,  3.0D0,  &
            237.0D0 ,   1.00000000D-24  ,  0.0D0,  &
            244.0D0 ,   1.00000000D-24  ,  0.0D0,  &
            243.0D0 ,   1.00000000D-24  ,  0.0D0,  &
            247.0D0 ,   1.00000000D-24  ,  0.0D0,  &
            247.0D0 ,   1.00000000D-24  ,  0.0D0,  &
            251.0D0 ,   1.00000000D-24  ,  0.0D0,  &
            254.0D0 ,   1.00000000D-24  ,  0.0D0/
!
!
!  Ionization potentials for first 99 species:
      DATA XI/&
!
!  Element Ionization potentials (eV) 
!           I     II      III     IV       V     VI     VII    VIII
!
            13.595D0,  0.0D0   , 0.0D0 ,  0.0D0   ,  0.0D0  ,  0.0D0  ,  0.0D0  ,  0.0D0 ,&
            24.580D0, 54.400D0,  0.0D0   ,  0.0D0  ,  0.0D0  ,  0.0D0  ,  0.0D0  ,  0.0D0  ,&
             5.392D0, 75.619D0,122.451D0,  0.0D0  ,  0.0D0  ,  0.0D0 ,  0.0D0,  0.0D0 ,&
             9.322D0, 18.206D0,153.850D0,217.713D0,  0.0D0  ,  0.0D0  ,  0.0D0 ,  0.0D0 ,&
             8.296D0, 25.149D0, 37.920D0,259.298D0,340.22D0,  0.0D0 ,  0.0D0  ,  0.0D0  ,&
            11.264D0, 24.376D0, 47.864D0, 64.476D0,391.99D0,489.98D0,  0.0D0 ,  0.0D0  ,&
            14.530D0, 29.593D0, 47.426D0, 77.450D0, 97.86D0,551.93D0,667.03D0,  0.0D0  ,&
            13.614D0, 35.108D0, 54.886D0, 77.394D0,113.87D0,138.08D0,739.11D0,871.39D0,&
            17.418D0, 34.980D0, 62.646D0, 87.140D0,114.21D0,157.12D0,185.14D0,953.6D0 ,&
            21.559D0, 41.070D0, 63.500D0, 97.020D0,126.30D0,157.91D0,207.21D0,239.0D0 ,&
             5.138D0, 47.290D0, 71.650D0, 98.880D0,138.37D0,172.09D0,208.44D0,264.16D0,&
             7.664D0, 15.030D0, 80.120D0,102.290D0,141.23D0,186.49D0,224.9D0 ,265.96D0,& 
             5.984D0, 18.823D0, 28.440D0,119.960D0,153.77D0,190.42D0,241.38D0,284.53D0,& 
             8.151D0, 16.350D0, 33.460D0, 45.140D0,166.73D0,205.11D0,246.41D0,303.07D0, &
            10.484D0, 19.720D0, 30.156D0, 51.354D0, 65.01D0,220.41D0,263.31D0,309.26D0,&
            10.357D0, 23.400D0, 35.000D0, 47.290D0, 72.50D0, 88.03D0,280.99D0,328.8D0 ,&
            12.970D0, 23.800D0, 39.900D0, 53.500D0, 67.80D0, 96.7D0 ,114.27D0,348.D03 ,&
            15.755D0, 27.620D0, 40.900D0, 59.790D0, 75.00D0, 91.3D0 ,124.0D0 ,143.46D0,&
             4.339D0, 31.810D0, 46.000D0, 60.900D0, 82.6D0 , 99.7D0 ,118.0D0 ,155.0D0 ,&
             6.111D0, 11.870D0, 51.210D0, 67.700D0, 84.39D0,109.0D0 ,128.0D0 ,147.0D0 ,&
             6.560D0, 12.890D0, 24.750D0, 73.900D0, 92.0D0 ,111.1D0 ,138.0D0 ,158.7D0 ,&
             6.830D0, 13.630D0, 28.140D0, 43.240D0, 99.8D0 ,120.0D0 ,140.8D0 ,168.5D0 ,&
             6.740D0, 14.200D0, 29.700D0, 48.000D0, 65.2D0 ,128.9D0 ,151.0D0 ,173.7D0 ,&
             6.763D0, 16.490D0, 30.950D0, 49.600D0, 73.0D0 , 90.6D0 ,161.1D0,184.7D0 ,&
             7.432D0, 15.640D0, 33.690D0, 53.000D0, 76.0D0 , 97.0D0 ,119.24D0,196.46D0,&
             7.870D0, 16.183D0, 30.652D0, 54.800D0, 75.0D0 , 99.1D0 ,125.0D0 ,151.06D0,&
             7.860D0, 17.060D0, 33.490D0, 51.300D0, 79.5D0 ,102.0D0 ,129.0D0 ,157.0D0 ,&
             7.635D0, 18.168D0, 35.170D0, 54.900D0, 75.5D0 ,108.0D0 ,133.0D0 ,162.0D0 ,&
             7.726D0, 20.292D0, 36.830D0, 55.200D0, 79.9D0 ,103.0D0 ,139.0D0 ,166.0D0 ,&
             9.394D0, 17.964D0, 39.722D0, 59.400D0, 82.6D0 ,108.0D0 ,134.0D0 ,174.0D0 ,&
             6.000D0,  20.509D0,   30.700D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, & 
             7.89944D0,15.93462D0, 34.058D0, 45.715D0,99.99D0,99.99D0,99.99D0,99.99D0,&    
             9.7887D0, 18.5892D0,  28.351D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &   
             9.750D0,21.500D0, 32.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0,  &  
            11.839D0,21.600D0, 35.900D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &   
            13.995D0,24.559D0, 36.900D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &   
             4.175D0,27.500D0, 40.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &   
             5.692D0,11.026D0, 43.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &   
             6.2171D0,12.2236D0, 20.5244D0,60.607D0,99.99D0,99.99D0,99.99D0,99.99D0, &   
             6.63390D0,13.13D0,23.17D0,34.418D0,80.348D0,99.99D0,99.99D0,99.99D0, &   
             6.879D0,14.319D0, 25.039D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0,&   
             7.099D0,16.149D0, 27.149D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             7.280D0,15.259D0, 30.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0,&   
             7.364D0,16.759D0, 28.460D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             7.460D0,18.070D0, 31.049D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0,&   
             8.329D0,19.419D0, 32.920D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             7.574D0,21.480D0, 34.819D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             8.990D0,16.903D0, 37.470D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             5.784D0,18.860D0, 28.029D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             7.342D0,14.627D0, 30.490D0,72.3D0,99.99D0,99.99D0,99.99D0,99.99D0,  & 
             8.639D0,16.500D0, 25.299D0,44.2D0,55.7D0,99.99D0,99.99D0,99.99D0,   &
             9.0096D0,18.600D0, 27.96D0, 37.4D0,58.7D0,99.99D0,99.99D0,99.99D0,   &
            10.454D0,19.090D0, 32.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
            12.12984D0,20.975D0,31.05D0,45.D0,54.14D0,99.99D0,99.99D0,99.99D0,   &
             3.893D0,25.100D0, 35.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             5.210D0,10.000D0, 37.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             5.580D0,11.060D0, 19.169D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             5.650D0,10.850D0, 20.080D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0,  & 
             5.419D0,10.550D0, 23.200D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             5.490D0,10.730D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             5.550D0,10.899D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             5.629D0,11.069D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             5.680D0,11.250D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             6.159D0,12.100D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             5.849D0,11.519D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             5.930D0,11.670D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             6.020D0,11.800D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             6.099D0,11.930D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             6.180D0,12.050D0, 23.700D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             6.250D0,12.170D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             6.099D0,13.899D0, 19.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             7.000D0,14.899D0, 23.299D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             7.879D0,16.200D0, 24.00D00, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             7.86404D0,17.700D0, 25.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             7.870D0,16.600D0, 26.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0,  & 
             8.500D0,17.000D0, 27.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             9.100D0,20.000D0, 28.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             8.95868D0,18.563D0,33.227D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             9.220D0,20.500D0, 30.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0,  & 
            10.430D0,18.750D0, 34.200D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0,  & 
             6.10829D0,20.4283D0,29.852D0,50.72D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             7.416684D0,15.0325D0,31.9373D0,42.33D0,69.0D0,99.99D0,99.99D0,99.99D0, &  
             7.285519D0,16.679D0, 25.563D0,45.32D0,56.0D0,88.D0,99.99D0,99.99D0,   &
             8.430D0,19.000D0, 27.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0,  & 
             9.300D0,20.000D0, 29.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0,  & 
            10.745D0,20.000D0, 30.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             4.000D0,22.000D0, 33.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             5.276D0,10.144D0, 34.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             6.900D0,12.100D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             6.000D0,12.000D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &  
             6.000D0,12.000D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &   
             6.000D0,12.000D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &   
             6.000D0,12.000D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &   
             6.000D0,12.000D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &   
             6.000D0,12.000D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &   
             6.000D0,12.000D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &   
             6.000D0,12.000D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &   
             6.000D0,12.000D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0, &    
             6.000D0,12.000D0, 20.000D0, 99.99D0,99.99D0,99.99D0,99.99D0,99.99D0/
!
	DO i=1,matom

	  adyp(i)=dyp(i)

	  DO j=1,8

	    axi(j,i)=xi(j,i)
	
	  ENDDO

	  DO j=1,3

	    ad(j,i)=d(j,i)
	
	  ENDDO

	ENDDO

 END SUBROUTINE state0


END MODULE statfun
